package
Version:
v0.0.0-...-bf8aa72
Opens a new window with list of versions in this module.
Published: Mar 12, 2022
License: MIT
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Postgres struct {
*sqlx.DB
}
Postgres is the primary database for the application.
Setup attempts configure and connect to the database
Config is used to configure a postgres sql server connection
ConnStr returns a postgres connection string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.