oncall

package
v0.0.0-...-bf8aa72 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2022 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Application

type Application struct {
	*fx.App
}

Application is a web service that powers the on call backend. It handles application start, dependency injection, and graceful shutdowns It wraps an uber fx app, so for detailed documentation please check the go doc at https://pkg.go.dev/go.uber.org/fx

func NewApplication

func NewApplication(options ...Option) Application

NewApplication constucts a on call backend application ready to be run.

type Option

type Option func(*settings)

func StartTimeout

func StartTimeout(dur time.Duration) Option

StartTimeout configures the start up timeout of the application

func StopTimeout

func StopTimeout(dur time.Duration) Option

StopTimeout configures the start up timeout of the application

Jump to