command

package
v0.0.0-...-bf8aa72 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 12, 2022 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidSlackToken  = errors.New("the token associated with command is not valid and cannot be trusted")
	ErrUnsupportedCommand = errors.New("the provided command is not supported")
)

Module exposes dependencies useful dealing with schedule related command processing

Functions

This section is empty.

Types

type Handler

type Handler interface {
	Handle(slack.SlashCommand) (any, error)
}

Handler is responsible for dealing with slash commands sent by slack. The result of a successful handle returns a data that can be returned to Slack

func NewHandler

func NewHandler(
	config config.SlackSettings,
	adder add.Handler,
	schedule schedule.Handler,
	withdrawer withdraw.Handler,
	swapper swap.Handler,
	overrider override.Handler,
	log *zap.Logger,
) Handler

Directories

Path Synopsis

Jump to