Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Module = fx.Provide( NewSlackVerifier, NewLogger, )
Module contains all the dependencies that power api middleware
Functions ¶
Types ¶
type SlackVerifier ¶
type SlackVerifier struct {
// contains filtered or unexported fields
}
SlackVerifier is used to ensure requests are from Slack
func NewSlackVerifier ¶
func NewSlackVerifier( settings config.SlackSettings, log *zap.Logger, ) *SlackVerifier
func (*SlackVerifier) Verify ¶
func (s *SlackVerifier) Verify(next httprouter.Handle) httprouter.Handle
Verify is a method that serves as a middle for requests handlers from Slack. Slack signs all requests with the application issued signing key, and this middleware verifies the request is legit, sending back an http error and returning before handling control to the next middleware
Click to show internal directories.
Click to hide internal directories.