Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Application ¶
Application is a web service that powers the on call backend. It handles application start, dependency injection, and graceful shutdowns It wraps an uber fx app, so for detailed documentation please check the go doc at https://pkg.go.dev/go.uber.org/fx
func NewApplication ¶
func NewApplication(options ...Option) Application
NewApplication constucts a on call backend application ready to be run.
Click to show internal directories.
Click to hide internal directories.